API
===
Documentation of the `ooetl` module and its submodules:
`extractors`, `loaders`, and `utils`.

ooetl
------
.. automodule:: ooetl
    :members:
    :undoc-members:
    :show-inheritance:

ooetl.extractors
-----------------
.. automodule:: ooetl.extractors
    :members:
    :undoc-members:
    :show-inheritance:


ooetl.loaders
--------------
.. automodule:: ooetl.loaders
    :members:
    :undoc-members:
    :show-inheritance:


